pub struct AuthRequest {
pub email: String,
pub password: String,
pub scope: AuthScope,
pub term: AuthDuration,
pub context: String,
}Expand description
Auth request to be sent to api/auth endpoint.
If credentials match a new access token will be generated and sent back to the caller. The token will be generated using information provided in the request.
Fields
email: Stringpassword: Stringscope: AuthScopeScope of information that shall be available when using the resulting token.
term: AuthDurationGeneral duration for which the resulting token shall be valid.
context: StringContext in which the resulting token is being requested, e.g. application name or other additional information.