comment_tree

Function comment_tree 

pub fn comment_tree(
    parent: Uuid,
    db: &Database,
) -> Result<(Vec<CommentNode>, usize)>
Formats a comment tree based on the comments found per specified parent. Attaches additional information to each comment node for convenience.

Returns a tuple of vec of nodes and total comment count.