Config

Struct Config 

pub struct Config {
Show 21 fields pub name: String, pub version: String, pub domain: String, pub address: SocketAddr, pub assets: Assets, pub tracing: Tracing, pub routers: Routers, pub auth: Auth, pub oauth: Oauth, pub registration: Registration, pub comments: Comments, pub email: Email, pub mailing: Mailing, pub payments: Payments, pub company: Company, pub plans: Vec<Plan>, pub users: Vec<User>, pub phrases: Vec<String>, pub dev: DevMode, pub init: Init, pub routes: Routes,
}
Application configuration. Defines all the aspects of the application that are to be handled on the micron level.

Sensible defaults

Configuration provided through Config::default() allows for quick setup of an application using the recommended workflow. It enables all available features and sets default values for paths, addresses, etc.

Using the struct update syntax one can initialize a new Config, making a few changes right in the definition.

let cfg = Config {
    tracing: Tracing {
        enabled: false,
        ..Default::default()
    },
    ..Default::default()
}

Fields

name: Stringversion: Stringdomain: String

Domain name pointing to the machine running the application.

address: SocketAddr

Address on which to serve the application. Defaults to 127.0.0.1:8080.

assets: Assetstracing: Tracingrouters: Routersauth: Authoauth: Oauthregistration: Registrationcomments: Commentsemail: Emailmailing: Mailingpayments: Paymentscompany: Company

Information about the company behind the application.

plans: Vec<Plan>

List of available subscription plans.

users: Vec<User>

List of initial users.

phrases: Vec<String>

List of phrases/quotes to be showed randomly on the app pages, because why not.

dev: DevMode

Development mode configuration.

init: Initroutes: Routes

Selectively enable/disable pre-made routes