pub struct DevMode {
pub enabled: bool,
pub autologin: Option<String>,
pub mock: bool,
pub mock_regen: bool,
}Expand description
NOTE: make sure to disable on production.
Fields
enabled: boolGlobal switch for all dev mode items.
autologin: Option<String>Automatic login flag. Includes the email of the user to be logged in.
mock: boolMocking flag for all the mocking behavior performed by this library.
mock_regen: boolRegenerative mocking behavior controls whether to regenerate mocks that are already present in the database.