pub struct Order {
pub id: OrderId,
pub user: UserId,
pub time: DateTime<Utc>,
pub status: OrderStatus,
pub mode: OrderMode,
pub items: Vec<Product>,
}Expand description
Single order describes an event where credits are to be subtracted from user in exchange for a number of items.
Fields
id: OrderIdUnique identifier for the order
user: UserIdId of the user connected to the order
time: DateTime<Utc>Time at which the order was initiated
status: OrderStatusCurrent status of the order
mode: OrderModeDescription of how the order was initiated
items: Vec<Product>List of product items included in the order
Implementations