pub struct Auth {
pub require_confirmed_email: bool,
}Fields
require_confirmed_email: boolSwitch defining whether user must have confirmed email to be able to successfully pass auth.
If true, users without confirmed email will be presented with ability to confirm their email. Otherwise the auth will be succesfull, and any functionality restrictions are up to the application.
This requirement doesn’t have any effect on the oauth process, as successful oauth requires verified email information from the third-party provider.